@@ -1,10 +1,12 @@
-from pydantic import BaseModel, StrictStr
-from cocoa.ui.styling.colors import Colorizer, HighlightColorizer
-from cocoa.ui.styling.attributes import Attributizer
-from cocoa.ui.config.mode import TerminalDisplayMode
 from typing import Dict, List, Literal
-from .letters import FormatterSet, SupportedLetters
 
+from pydantic import BaseModel, StrictStr
+
+from cocoa.ui.config.mode import TerminalDisplayMode
+from cocoa.ui.styling.attributes import Attributizer
+from cocoa.ui.styling.colors import Colorizer, HighlightColorizer
+
+from .letters import FormatterSet, SupportedFonts, SupportedLetters
 
 HeaderHorizontalAlignment = Literal["left", "center", "right"]
 HeaderVerticalAlignment = Literal["top", "center", "bottom"]
@@ -19,3 +21,4 @@ class HeaderConfig(BaseModel):
     attributes: List[Attributizer] | None = None
     terminal_mode: TerminalDisplayMode = "compatability"
     formatters: Dict[SupportedLetters, FormatterSet] | None = None
+    font: SupportedFonts = "cyberpunk"
